Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorptff2003-11-17 10:17:08 +0000
committerptff2003-11-17 10:17:08 +0000
commit4c6ae9dae1fc96f9fd302751a25b14b4f972fb0f (patch)
tree1ef1e3371a0904e9bc298920b31c58e7d815d5d5 /org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/AstNode.java
parentb136d601b8b65cbe6a937874c4ada8fd9c6f056d (diff)
downloadeclipse.jdt.core-4c6ae9dae1fc96f9fd302751a25b14b4f972fb0f.tar.gz
eclipse.jdt.core-4c6ae9dae1fc96f9fd302751a25b14b4f972fb0f.tar.xz
eclipse.jdt.core-4c6ae9dae1fc96f9fd302751a25b14b4f972fb0f.zip
45112v_382a
Diffstat (limited to 'org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/AstNode.java')
-rw-r--r--org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/AstNode.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/AstNode.java b/org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/AstNode.java
index 868b2c6e5c..25d36f8581 100644
--- a/org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/AstNode.java
+++ b/org.eclipse.jdt.core/compiler/org/eclipse/jdt/internal/compiler/ast/AstNode.java
@@ -37,7 +37,7 @@ public abstract class AstNode implements BaseTypes, CompilerModifiers, TypeConst
public final static int Bit13 = 0x1000; // depth (name ref, msg)
public final static int Bit14 = 0x2000; // assigned (reference lhs)
public final static int Bit15 = 0x4000; // is unnecessary cast (expression)
- public final static int Bit16 = 0x8000; // in annotation (name ref, type ref, msg)
+ public final static int Bit16 = 0x8000; // in javadoc comment (name ref, type ref, msg)
public final static int Bit17 = 0x10000;
public final static int Bit18 = 0x20000;
public final static int Bit19 = 0x40000;
@@ -111,8 +111,8 @@ public abstract class AstNode implements BaseTypes, CompilerModifiers, TypeConst
// for compilation unit
public static final int HasAllMethodBodies = Bit5;
- // for references in annotations
- public static final int InsideAnnotation = Bit16;
+ // for references in Javadoc comments
+ public static final int InsideJavadoc = Bit16;
public AstNode() {

Back to the top